@@ -62,7 +62,7 @@ class TrivyScan(ToolGateway):
             except Exception as e:
                 logger.error(f"Error installing trivy: {e}")
 
-    def scan_image(self, prefix, image_name, result_file, base_image):
+    def scan_image(self, prefix, image_name, result_file, base_image, is_compressed_file=False):
         command = [
             prefix,
             "--scanners",
@@ -72,7 +72,12 @@ class TrivyScan(ToolGateway):
             "-o",
             result_file,
         ]
-        command.extend(["--quiet", "image", image_name])
+        
+        if is_compressed_file:
+            command.extend(["--quiet", "image", "--input", image_name])
+        else:
+            command.extend(["--quiet", "image", image_name])
+            
         try:
             subprocess.run(
                 command,
@@ -88,7 +93,7 @@ class TrivyScan(ToolGateway):
         except Exception as e:
             logger.error(f"Error during image scan of {image_name}: {e}")
 
-    def _generate_sbom(self, prefix, image_name, remoteconfig):
+    def _generate_sbom(self, prefix, image_name, remoteconfig, is_compressed_file=False):
         result_sbom = f"{image_name.replace('/', '_')}_SBOM.json"
         command = [
             prefix,
@@ -98,7 +103,10 @@ class TrivyScan(ToolGateway):
             "--output",
             result_sbom
         ]
-        command.extend(["--quiet", image_name])
+        if is_compressed_file:
+            command.extend(["--quiet", "--input", image_name])
+        else:
+            command.extend(["--quiet", image_name])
         try:
             subprocess.run(
                 command,
@@ -114,7 +122,7 @@ class TrivyScan(ToolGateway):
         except Exception as e:
             logger.error(f"Error generating SBOM: {e}")
 
-    def run_tool_container_sca(self, remoteconfig, secret_tool, token_engine_container, image_name, result_file, base_image, exclusions, generate_sbom):
+    def run_tool_container_sca(self, remoteconfig, secret_tool, token_engine_container, image_name, result_file, base_image, exclusions, generate_sbom, is_compressed_file=False):
         trivy_version = remoteconfig["TRIVY"]["TRIVY_VERSION"]
         os_platform = platform.system()
         arch_platform = platform.architecture()[0]
@@ -136,9 +144,9 @@ class TrivyScan(ToolGateway):
             return None
 
         image_scanned = (
-            self.scan_image(command_prefix, image_name, result_file, base_image)
+            self.scan_image(command_prefix, image_name, result_file, base_image, is_compressed_file)
         )
         if generate_sbom:
-            sbom_components = self._generate_sbom(command_prefix, image_name, remoteconfig)
+            sbom_components = self._generate_sbom(command_prefix, image_name, remoteconfig, is_compressed_file)
 
         return image_scanned, sbom_components
